==> segatex-4.30.tgz: segatex-4.30/src/semanage_core_login_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECORELOGINPROCESS_H
#define SEMANAGECORELOGINPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qregexp.h> 
//#include <qvaluevector.h> 
#include <qlabel.h> 
#include <qtextedit.h>


class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class SemanageCoreLoginProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreLoginProcess(QWidget *parent = 0, const char *name = 0);
	int i;
	QString outputfile_str_common;
	QString outputfile_str_common2;
	QString textEdit1_str;
public slots:
	void semanage_core_base_login_process();
signals:
//	void semanage_core_login_prosess_close_button_clicked();
protected:
private slots:
	//void close_button_clicked();
	void add_button_clicked();
	void delete_button_clicked();
	void modify_button_clicked();
	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void delete_button_clicked_process(QString textEdit3_str);
	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str);
	void readFromOutputFile();
public:
private:
	QPushButton *addButton;
	QPushButton *deleteButton;
	QPushButton *modifyButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QTextEdit *textEdit2;
	QTextEdit *textEdit3;
	QProcess *process;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QHBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QHBoxLayout *thirdLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLabel *semanageEditLabel3;
        QLabel *semanageEditLabel4;
        QLabel *semanageEditLabel5;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QLineEdit *semanageEditLineEdit3;
        QLineEdit *semanageEditLineEdit4;
        QLineEdit *semanageEditLineEdit5;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;
        QString semanageEditLineEdit4_str;
        QString semanageEditLineEdit5_str;
        QString semanageEditLineEdit_str_pp;
};

#endif

==> segatex-4.50.tgz: segatex-4.50/src/semanage_core_login_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECORELOGINPROCESS_H
#define SEMANAGECORELOGINPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qregexp.h> 
//#include <qvaluevector.h> 
#include <qlabel.h> 
#include <qtextedit.h>


class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class SemanageCoreLoginProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreLoginProcess(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
//	void semanage_core_login_prosess_close_button_clicked();
protected:
private slots:
	void semanage_core_base_login_process();
	//void close_button_clicked();
	void add_button_clicked();
	void delete_button_clicked();
	void modify_button_clicked();
	void add_button_clicked_process(QString textEdit1_str, QString textEdit2_str);
	void delete_button_clicked_process(QString textEdit3_str);
	void modify_button_clicked_process(QString textEdit4_str, QString textEdit5_str);
	void readFromOutputFile();
public:
private:
	QPushButton *addButton;
	QPushButton *deleteButton;
	QPushButton *modifyButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	//QTextEdit *textEdit2;
	//QTextEdit *textEdit3;
	//QProcess *process;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QHBoxLayout *leftLayout;
	QHBoxLayout *rightLayout;
	QHBoxLayout *thirdLayout;
	QVBoxLayout *middleLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLabel *semanageEditLabel2;
        QLabel *semanageEditLabel3;
        QLabel *semanageEditLabel4;
        QLabel *semanageEditLabel5;
        QLineEdit *semanageEditLineEdit;
        QLineEdit *semanageEditLineEdit2;
        QLineEdit *semanageEditLineEdit3;
        QLineEdit *semanageEditLineEdit4;
        QLineEdit *semanageEditLineEdit5;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit2_str;
        QString semanageEditLineEdit3_str;
        QString semanageEditLineEdit4_str;
        QString semanageEditLineEdit5_str;
        QString semanageEditLineEdit_str_pp;
};

#endif
